@@ -1,5 +1,7 @@
 open StdLabels
 
+let compunit_name Cmo_format.{ cu_name = Compunit name ; _ } = name
+
 let units fn =
   (* The cma format is documented in typing/cmo_format.mli in the compiler sources *)
   let ic = open_in_bin fn in
@@ -11,5 +13,5 @@ let units fn =
   let toc = (input_value ic : Cmo_format.library) in
   close_in ic;
 
-  List.map toc.lib_units ~f:(fun cu -> cu.Cmo_format.cu_name)
+  List.map toc.lib_units ~f:compunit_name
   |> List.sort ~cmp:String.compare
